#
# Cookbook Name:: MySql
# Recipe:: default
#
# Copyright 2012, inConcert
#
# All rights reserved - Do Not Redistribute
#


#
# make helper methods available inside templates.
#
#class Erubis::Context
#	include Redis::Helpers
#end

class Erubis::Context
  include MySql::GenericHelpers
end

#Chequeos iniciales ====================================================
if not node["platform"] == "ubuntu" then
	raise "El Sistema Operativo debe ser UBUNTU"
end

bash "[MYSQL] Check previous version of MySQL" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	mysqlInstall=`dpkg -l | grep mysql-client-5.7`
	if [ ! "$mysqlInstall" == '' ]; then
		echo "Existe una version previa de MySQL instalada. Debe desinstalar esto antes de correr el instalador."
		exit 1
	fi
	mysqlInstall=`dpkg -l | grep mysql-client-core-5.7`
	if [ ! "$mysqlInstall" == '' ]; then
		echo "Existe una version previa de MySQL instalada. Debe desinstalar esto antes de correr el instalador."
		exit 1
	fi
  EOH
end

if node.mysql.install_type == "standalone" then
	include_recipe "mysql::firewall"
end

#Descargo bundle de mySQL ====================================================
bash "[MYSQL] Download mysql-cluster_#{node.mysql.version_mysql}_amd64.deb-bundle.tar" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	mkdir -p /tmp/mysql_packages
	cd /tmp/mysql_packages
	wget -q http://#{node.mysql.sources.server}/repo/mysql-cluster_#{node.mysql.version_mysql}_amd64.deb-bundle.tar -O /tmp/mysql_packages/mysql-cluster_#{node.mysql.version_mysql}_amd64.deb-bundle.tar
	touch /tmp/mysql_packages/.downloadOK
  EOH
  not_if "ls /tmp/mysql_packages/.downloadOK"
end

bash "[MYSQL] unpack mysql-cluster_#{node.mysql.version_mysql}_amd64.deb-bundle.tar" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	cd /tmp/mysql_packages
	tar -xvf /tmp/mysql_packages/mysql-cluster_#{node.mysql.version_mysql}_amd64.deb-bundle.tar
  EOH
end


#Instalo Cluster Manager ====================================================
bash "[MYSQL] Install MYSQL_#{node.grafana.version_grafana} Cluster Manager" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	cd /tmp/mysql_packages/
	dpkg -i mysql-cluster-community-management-server_#{node.mysql.version_mysql}_amd64.deb
	mkdir -p /var/lib/mysql-cluster
	mkdir -p /var/log/mysql-cluster
  EOH
end

template "/var/lib/mysql-cluster/config.ini" do
  source "config.ini.erb"
  owner  "root"
  group  "root"
  mode   "0644"
end

cookbook_file "/etc/systemd/system/ndb_mgmd.service" do
  source "ndb_mgmd.service"
  owner   "root"
  group   "root"
  mode    "0644"
end

bash "[MYSQL] Habilito servicio de Cluster Manager" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	systemctl daemon-reload
	systemctl enable ndb_mgmd
  EOH
end

#Instalo ndb Data Node ====================================================
package "libclass-methodmaker-perl"

bash "[MYSQL] Install MYSQL_#{node.grafana.version_grafana} Data Node" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	cd /tmp/mysql_packages/
	dpkg -i mysql-cluster-community-data-node_#{node.mysql.version_mysql}_amd64.deb
	mkdir -p #{node.mysql.mysql_data_file_directories}
  EOH
end

template "/etc/my.cnf" do
  source "my.cnf.erb"
  owner  "root"
  group  "root"
  mode   "0644"
end

cookbook_file "/etc/systemd/system/ndbd.service" do
  source "ndbd.service"
  owner   "root"
  group   "root"
  mode    "0644"
end

bash "[MYSQL] Habilito servicio de NDB" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	systemctl daemon-reload
	systemctl enable ndbd
  EOH
end

#Instalo MySQL Server ====================================================
package "libaio1"
package "libmecab2"
package "libssl1.1" do
	action :upgrade
end

bash "[MYSQL] Install MYSQL_#{node.grafana.version_grafana} MySQL Server" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
	cd /tmp/mysql_packages/
	dpkg -i mysql-common_#{node.mysql.version_mysql}_amd64.deb 
	dpkg -i mysql-cluster-community-client-plugins_#{node.mysql.version_mysql}_amd64.deb
	dpkg -i mysql-cluster-community-client-core_#{node.mysql.version_mysql}_amd64.deb
	dpkg -i mysql-cluster-community-client_#{node.mysql.version_mysql}_amd64.deb
	dpkg -i mysql-client_#{node.mysql.version_mysql}_amd64.deb
	dpkg -i mysql-cluster-community-server-core_#{node.mysql.version_mysql}_amd64.deb
	dpkg -i mysql-cluster-community-server_#{node.mysql.version_mysql}_amd64.deb
	dpkg -i mysql-cluster-community-server-debug_#{node.mysql.version_mysql}_amd64.deb
	
	dpkg -i mysql-server_#{node.mysql.version_mysql}_amd64.deb
  EOH
end

template "/etc/mysql/mysql.cnf" do
  source "mysql.cnf.erb"
  owner  "root"
  group  "root"
  mode   "0644"
end

#Instalar Exporters para Grafana ====================================================
bash "[NODE_EXPLORER] Download Node Exporter" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
    wget http://#{node.mysql.sources.server}/repo/node_exporter-1.3.1.linux-amd64.tar.gz
  EOH
end

bash "[NODE_EXPLORER] Install Node Exporter" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
    mkdir /etc/prometheus_exporters
    sudo tar zxf node_exporter-1.3.1.linux-amd64.tar.gz -C /etc/prometheus_exporters
  EOH
end

cookbook_file "/etc/systemd/system/node_exporter.service" do
  source "node_exporter.service"
  owner   "root"
  group   "root"
  mode    "0644"
end

bash "[NODE_EXPLORER] Enable and start exporter" do
  cwd "/etc/init.d"
  code <<-EOC
    systemctl daemon-reload
    systemctl enable node_exporter
	systemctl start node_exporter
  EOC
end
#

#Instalar Node Exporter  ====================================================
bash "[MYSQLD_EXPLORER] Install Mysqld Exporter" do
  user    "root"
  cwd     "/tmp"
  code  <<-EOH
    mkdir -p /etc/prometheus_exporters/mysqld_exporter
  EOH
end

cookbook_file "/etc/prometheus_exporters/mysqld_exporter/mysqld_exporter" do
  source "mysqld_exporter"
  owner   "root"
  group   "root"
  mode    "0744"
end

cookbook_file "/etc/prometheus_exporters/mysqld_exporter/my.cnf" do
  source "my.cnf"
  owner   "root"
  group   "root"
  mode    "0644"
end

cookbook_file "/etc/systemd/system/mysql_exporter.service" do
  source "mysql_exporter.service"
  owner   "root"
  group   "root"
  mode    "0644"
end


bash "[MYSQLD_EXPLORER] Enable and start exporter" do
  cwd "/etc/init.d"
  code <<-EOC
    systemctl daemon-reload
    systemctl enable mysql_exporter
    systemctl start mysql_exporter
  EOC
end
